@@ -8,6 +8,8 @@ import sys
 import os
 from datetime import datetime, timedelta
 
+from PyQt4.QtGui import QApplication
+app = QApplication(sys.argv)
 from PyQt4 import QtCore, QtGui
 
 from netstory_ui import Ui_MainWindow
@@ -426,8 +428,8 @@ class SortTableWidgetItem(QtGui.QTableWidgetItem):
         return self.sort_key < other.sort_key
 
 
-if __name__ == "__main__":
-    app = QtGui.QApplication(sys.argv)   
+if __name__ == "__main__":   
+    #app = QtGui.QApplication(sys.argv)
     dataform = DataForm()
     dataform.show()
     sys.exit(app.exec_())
\ No newline at end of file
